0.4.3
+++++
Add Twitter DMs.

0.4.2
+++++

Adds ReCaptchaContactForm

0.4.1
+++++
Refactoring makes contrib contact views easier to use.
Implement reply-to for Django mailer.

0.4
+++
Frist semi-stable release.
Adds attachments, allows sending messages without a subject.
python -m letter does things now.
Allow the setting of replyto headers.
Adds SMS messages via Twilio
Add Tweets via tweepy

0.3.1
+++++
Add extra composability to the django contrib view.

0.3
+++
Add django contrib views for use with contact forms

0.2.2.1
+++++++
Fix bug sending mails to multpile recipients.
Add Bcc and Cc fields.

0.2.0
++++++++++++++++++++++++++++++
Stop relying on Mailtools.
letter.Letter interface for SMTP messages as well.

0.1.0
++++++++++++++++++
Add a Django compatibility layer for composing emails there.
Write the letter.Letter class based interface.

0.0.3
++++++++++++++++++
Forgive nonexistant directories on the temlpate search path.

0.0.2 (09 10 2012)
++++++++++++++++++

Initial version
